<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/core/RUnit.cpp" line="+273"/>
        <source>None</source>
        <translatorcomment>--exact match--
--file: es.po--
Ninguno
ninguno
 F80h, ERROR 1: Codigo Funcion Inexistente </translatorcomment>
        <translation>Ninguno</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inch</source>
        <translatorcomment>--exact match--
--file: es.po--
Para mediciones &quot;Ingenieriles&quot; y &quot;Arquitectónicas&quot;, la unidad debe ser la Pulgada.
Para mediciones &quot;Ingenieriles&quot; y &quot;Arquitectónicas&quot;, la unidad debe ser la Pulgada
Pulgadas</translatorcomment>
        <translation>Pulgadas</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Foot</source>
        <translatorcomment>--exact match--
--file: es.po--
Pie</translatorcomment>
        <translation>Pie</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mile</source>
        <translatorcomment>--exact match--
--file: UnitSettings_es.ts--
Milla</translatorcomment>
        <translation>Milla</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Millimeter</source>
        <translatorcomment>--exact match--
--file: es.po--
Milímetro
Milímetros</translatorcomment>
        <translation>Milímetro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Centimeter</source>
        <translatorcomment>--exact match--
--file: es.po--
Centímetro
Centímetros</translatorcomment>
        <translation>Centímetro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Meter</source>
        <translatorcomment>--exact match--
--file: es.po--
(Des)Activar signo de diámetro
ø (Diámetro)</translatorcomment>
        <translation>Metro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Kilometer</source>
        <translatorcomment>--exact match--
--file: UnitSettings_es.ts--
Kilómetro</translatorcomment>
        <translation>Kilómetro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Microinch</source>
        <translatorcomment>--exact match--
--file: UnitSettings_es.ts--
Micro pulgada</translatorcomment>
        <translation>Micro pulgada</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mil</source>
        <translatorcomment>--exact match--
--file: UnitSettings_es.ts--
[0B80-0BFF] Tamil
Tamil</translatorcomment>
        <translation>Mil</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Yard</source>
        <translatorcomment>--exact match--
--file: UnitSettings_es.ts--
Yarda</translatorcomment>
        <translation>Yarda</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Angstrom</source>
        <translatorcomment>--exact match--
--file: UnitSettings_es.ts--
Angstrom</translatorcomment>
        <translation>Angstrom</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Nanometer</source>
        <translatorcomment>--exact match--
--file: UnitSettings_es.ts--
Nanómetro</translatorcomment>
        <translation>Nanómetro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Micron</source>
        <translatorcomment>--exact match--
--file: UnitSettings_es.ts--
Micrón</translatorcomment>
        <translation>Micrón</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decimeter</source>
        <translatorcomment>--exact match--
--file: UnitSettings_es.ts--
Desímetro</translatorcomment>
        <translation>Desímetro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decameter</source>
        <translatorcomment>--exact match--
--file: UnitSettings_es.ts--
Decámetro</translatorcomment>
        <translation>Decámetro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hectometer</source>
        <translatorcomment>--exact match--
--file: UnitSettings_es.ts--
Hectómetro</translatorcomment>
        <translation>Hectómetro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Gigameter</source>
        <translatorcomment>--exact match--
--file: UnitSettings_es.ts--
Gigámetro</translatorcomment>
        <translation>Gigámetro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Astro</source>
        <translatorcomment>--exact match--
--file: UnitSettings_es.ts--
Astro</translatorcomment>
        <translation>Astro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Lightyear</source>
        <translatorcomment>--exact match--
--file: UnitSettings_es.ts--
Años Luz</translatorcomment>
        <translation>Años Luz</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Parsec</source>
        <translatorcomment>--exact match--
--file: UnitSettings_es.ts--
Parsec</translatorcomment>
        <translation>Parsec</translation>
    </message>
</context>
<context>
    <name>RColor</name>
    <message>
        <location filename="../src/core/RColor.cpp" line="+287"/>
        <source>By Layer</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
Por Capa</translatorcomment>
        <translation>Por Capa</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
Por Bloque</translatorcomment>
        <translation>Por Bloque</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Red</source>
        <translatorcomment>--exact match--
--file: es.po--
&amp;Rehacer
Rehacer
Rehace última orden</translatorcomment>
        <translation>Rojo</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Yellow</source>
        <translatorcomment>--exact match--
--file: es.po--
Amarillo
Fijar color de trayecto a amarillo:</translatorcomment>
        <translation>Amarillo</translation>
    </message>
    <message>
        <location line="-4"/>
        <source>Green</source>
        <translatorcomment>--exact match--
--file: es.po--
Verde
&amp;Verde:</translatorcomment>
        <translation>Verde</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Cyan</source>
        <translatorcomment>--exact match--
--file: es.po--
Cian
Fijar color de trayecto a cian:</translatorcomment>
        <translation>Cian</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Blue</source>
        <translatorcomment>--exact match--
--file: es.po--
Azul
Azul:
Función azul</translatorcomment>
        <translation>Azul</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Magenta</source>
        <translatorcomment>--exact match--
--file: es.po--
Magenta
Fijar color de trayecto a magenta:</translatorcomment>
        <translation>Magenta</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Orange</source>
        <translation>Naranja</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Red</source>
        <translation>Rojo oscuro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Green</source>
        <translation>Verde oscuro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Blue</source>
        <translation>Azul oscuro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Cyan</source>
        <translation>Ciánico oscuro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Magenta</source>
        <translation>Magenta oscuro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Yellow</source>
        <translation>Amarillo oscuro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black</source>
        <translatorcomment>--exact match--
--file: es.po--
Blanco / Negro
Negro</translatorcomment>
        <translation>Negro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>White</source>
        <translatorcomment>--exact match--
--file: es.po--
Blanco / Negro
Blanca</translatorcomment>
        <translation>Blanca</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Gray</source>
        <translatorcomment>--exact match--
--file: es.po--
Gris
gris claro</translatorcomment>
        <translation>Gris</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Light Gray</source>
        <translatorcomment>--exact match--
--file: artisan_es.ts--
gris claro</translatorcomment>
        <translation>Gris claro</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Others...</source>
        <translatorcomment>--exact match--
--file: Text_es.ts--
Otros...</translatorcomment>
        <translation>Otros...</translation>
    </message>
</context>
<context>
    <name>RDocumentVariables</name>
    <message>
        <location filename="../src/core/RDocumentVariables.cpp" line="+45"/>
        <source>Current Layer ID</source>
        <translation>ID de la capa actual</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drawing Unit</source>
        <translation>Unidad de dibujo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>Escala de tipo de línea</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension Font</source>
        <translation>Fuente de cota</translation>
    </message>
</context>
<context>
    <name>REntity</name>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+92"/>
        <source>Block</source>
        <translatorcomment>--exact match--
--file: Block_es.ts--
&amp;Bloque
Bloque
Lista de bloques</translatorcomment>
        <translation>Bloque</translation>
    </message>
    <message>
        <source>Referenced Block</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Bloque</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="+66"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+1"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="+82"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+72"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+73"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>X</source>
        <translatorcomment>--exact match--
--file: es.po--
Saliendo de la aplicación...
Saliendo de la aplicación
Exportando el dibujo...</translatorcomment>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-3"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Position</source>
        <translatorcomment>--exact match--
--file: es.po--
Especifique posición de la línea de cota o introduzca ángulo:
Especifique posición de la línea de cota o introduzca ángulo
Especifique posición</translatorcomment>
        <translation>Posición</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="-1"/>
        <source>Pixel Unit</source>
        <translation>Pixel unidades</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Origin</source>
        <translation>Origen</translation>
    </message>
    <message>
        <location line="-1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-1"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-1"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>Y</source>
        <translatorcomment>--exact match--
--file: es.po--
Ubicando las Bibliotecas..
Ubicando las Bibliotecas
&amp;Modificar</translatorcomment>
        <translation>Y</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+10"/>
        <source>Z</source>
        <translatorcomment>--exact match--
--file: es.po--
Mosaico &amp;horizontal
Mosaico horizontal
Ocultar todo</translatorcomment>
        <translation>Z</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layout</source>
        <translation>Presentación</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-7"/>
        <source>Scale</source>
        <translatorcomment>--exact match--
--file: es.po--
Escalar
E&amp;scala</translatorcomment>
        <translation>Escalar</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angle</source>
        <translatorcomment>--exact match--
--file: es.po--
Introducir ángulo:
Introducir ángulo
Introduzca ángulo en línea de cota:</translatorcomment>
        <translation>Ángulo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Columns</source>
        <translation>Columnas</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Rows</source>
        <translation>Filas</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Column Spacing</source>
        <translation>Espacio entre columnas</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Row Spacing</source>
        <translation>Espacio entre filas</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attributes</source>
        <translation>Atributos</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="+87"/>
        <location filename="../src/core/RObject.cpp" line="+66"/>
        <source>Type</source>
        <translatorcomment>--exact match--
--file: es.po--
Tipo de línea:
Tipo de Línea
Tipo de Ordinal</translatorcomment>
        <translation>Tipo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Block ID</source>
        <translation>Bloque ID</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layer</source>
        <translatorcomment>--exact match--
--file: es.po--
&amp;Capa
Capa
Lista de Capas</translatorcomment>
        <translation>Capa</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+99"/>
        <source>Linetype</source>
        <translatorcomment>--exact match--
--file: LinetypeSettings_es.ts--
Tipo de línea por defecto
Tipo de línea</translatorcomment>
        <translation>Tipo de línea</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>Escala de tipo de línea</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Lineweight</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Grosor de línea</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="-2"/>
        <source>Color</source>
        <translatorcomment>--exact match--
--file: es.po--
Colores
&amp;Color puntos rejilla:</translatorcomment>
        <translation>Color</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Displayed Color</source>
        <translation>Color muestra</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Draw Order</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Orden de dibujo</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Boundary</source>
        <translation>Límite</translation>
    </message>
    <message>
        <location line="-3"/>
        <location filename="../src/core/RLayout.cpp" line="+3"/>
        <source>Left</source>
        <translation>Izquierda</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Bottom</source>
        <translation>Parte inferior</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Right</source>
        <translation>Derecha</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Top</source>
        <translation>Parte superior</translation>
    </message>
    <message>
        <location filename="../src/core/RObject.cpp" line="-1"/>
        <location filename="../src/core/RPropertyTypeId.cpp" line="+108"/>
        <source>Custom</source>
        <translation>Personalizado</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Handle</source>
        <translation>Handle</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Protected</source>
        <translation>Protegida</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="+2"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
        <source>Width</source>
        <translation>Ancho</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1"/>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <location line="+0"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+1"/>
        <source>Height</source>
        <translation>Altura</translation>
    </message>
    <message>
        <location filename="../src/core/RTextBasedEntity.cpp" line="-3"/>
        <source>Simple</source>
        <translation>Simple</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Text Position</source>
        <translation>Posición del texto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plain Text</source>
        <translation>Texto plano</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Font Name</source>
        <translation>Nombre de la fuente</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Height</source>
        <translation>Altura del texto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Angle</source>
        <translation>Ángulo del texto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>X Scale</source>
        <translation>Escala X</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bold</source>
        <translation>Negrita</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Italic</source>
        <translation>Cursivo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Line Spacing</source>
        <translation>Espacio entre líneas</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Alignment</source>
        <translation>Alineación</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Horizontal</source>
        <translation>Horizontal</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Vertical</source>
        <translation>Vertical</translation>
    </message>
    <message>
        <location filename="../src/core/RViewportEntity.cpp" line="+2"/>
        <source>Rotation</source>
        <translation>Rotación</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>On</source>
        <translation>Encendido</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Center</source>
        <translation>Vista centro</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Target</source>
        <translation>Vista objetivo</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Overall</source>
        <translation>Overall</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="-6"/>
        <location filename="../src/core/RLayer.cpp" line="-8"/>
        <location filename="../src/core/RLayout.cpp" line="-24"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>Líneas ocultas</translation>
    </message>
    <message>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Off</source>
        <translation>Inactivo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Frozen</source>
        <translation>Congelada</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Locked</source>
        <translation>Bloqueado</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Collapsed</source>
        <translation>Doblado</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plottable</source>
        <translation>Trazable</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Snappable</source>
        <translation>Ajustable</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Off is Freeze</source>
        <translation>Apagado es congelarse</translation>
    </message>
    <message>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Tab Order</source>
        <translation>Orden de tabulación</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Limits</source>
        <translation>Min límites</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Limits</source>
        <translation>Max límites</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Insertion Base</source>
        <translation>Base de inserción</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Extents</source>
        <translation>Min extensión</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Extents</source>
        <translation>Max extensión</translation>
    </message>
    <message>
        <source>Plot Margins</source>
        <translation type="vanished">Márgenes de trazado</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceData.cpp" line="+627"/>
        <source>Circular (recursive) block referencing detected:</source>
        <translation>Se detectó una referencia de bloque circular (recursiva):</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block name:</source>
        <translation>Nombre del bloque:</translation>
    </message>
</context>
<context>
    <name>RGuiAction</name>
    <message>
        <location filename="../src/core/RGuiAction.cpp" line="+184"/>
        <source>Requires selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Requiere una selección</translation>
    </message>
</context>
<context>
    <name>RLayer</name>
    <message>
        <source>Name</source>
        <translation type="vanished">Nombre</translation>
    </message>
    <message>
        <source>Frozen</source>
        <translation type="vanished">Oculto</translation>
    </message>
    <message>
        <source>Hidden</source>
        <translation type="vanished">Líneas ocultas</translation>
    </message>
    <message>
        <source>Locked</source>
        <translation type="vanished">Bloqueado</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="vanished">Color</translation>
    </message>
    <message>
        <source>Linetype</source>
        <translation type="vanished">Tipo de línea</translation>
    </message>
    <message>
        <source>Lineweight</source>
        <translation type="vanished">Grosor de línea</translation>
    </message>
</context>
<context>
    <name>RLinetype</name>
    <message>
        <source>By Layer</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
Por Capa</translatorcomment>
        <translation type="vanished">Por Capa</translation>
    </message>
    <message>
        <source>By Block</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
Por Bloque</translatorcomment>
        <translation type="vanished">Por Bloque</translation>
    </message>
    <message>
        <source>Continuous</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
Contínua
CONTROL CONTINUADO</translatorcomment>
        <translation type="vanished">Contínua</translation>
    </message>
    <message>
        <source>Dot</source>
        <translatorcomment>--exact match--
--file: qtiplot_es.ts--
Puntos de cuad&amp;rícula:
Puntos de cuad&amp;rícula
Puntos de cuadrícula:</translatorcomment>
        <translation type="vanished">Puntos</translation>
    </message>
    <message>
        <source>Dot (small)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
Puntos juntos
Punto raya (pequeña)</translatorcomment>
        <translation type="vanished">Puntos (juntos)</translation>
    </message>
    <message>
        <source>Dot (large)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
Puntos separados
Punto raya (grande)</translatorcomment>
        <translation type="vanished">Puntos (separados)</translation>
    </message>
    <message>
        <source>Dash</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
Raya
Raya (pequeña)</translatorcomment>
        <translation type="vanished">Raya</translation>
    </message>
    <message>
        <source>Dash (small)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
Raya (pequeña)</translatorcomment>
        <translation type="vanished">Raya (pequeña)</translation>
    </message>
    <message>
        <source>Dash (large)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
Raya (grande)</translatorcomment>
        <translation type="vanished">Raya (grande)</translation>
    </message>
    <message>
        <source>Dash Dot</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
Punto raya
Punto raya (pequeña)</translatorcomment>
        <translation type="vanished">Punto raya</translation>
    </message>
    <message>
        <source>Dash Dot (small)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
Punto raya (pequeña)</translatorcomment>
        <translation type="vanished">Punto raya (pequeña)</translation>
    </message>
    <message>
        <source>Dash Dot (large)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
Punto raya (grande)</translatorcomment>
        <translation type="vanished">Punto raya (grande)</translation>
    </message>
    <message>
        <source>Divide</source>
        <translatorcomment>--exact match--
--file: Divide_es.ts--
Raya 2 puntos
Partir</translatorcomment>
        <translation type="vanished">Partir</translation>
    </message>
    <message>
        <source>Divide (small)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
Raya 2 puntos (pequeña)</translatorcomment>
        <translation type="vanished">Raya 2 puntos (pequeña)</translation>
    </message>
    <message>
        <source>Divide (large)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
Raya 2 puntos (grande)</translatorcomment>
        <translation type="vanished">Raya 2 puntos (grande)</translation>
    </message>
    <message>
        <source>Center</source>
        <translatorcomment>--exact match--
--file: es.po--
Arco: centro, punto, ángulos
&amp;Centro, Punto, Angulo</translatorcomment>
        <translation type="vanished">Centro</translation>
    </message>
    <message>
        <source>Center (small)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
Rayas larga corta (pequeño)</translatorcomment>
        <translation type="vanished">Rayas larga corta (pequeño)</translation>
    </message>
    <message>
        <source>Center (large)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
Rayas larga corta (grande)</translatorcomment>
        <translation type="vanished">Rayas larga corta (grande)</translation>
    </message>
    <message>
        <source>Border</source>
        <translatorcomment>--exact match--
--file: qtiplot_es.ts--
Borde
2 rayas 1 punto (pequeño)</translatorcomment>
        <translation type="vanished">Borde</translation>
    </message>
    <message>
        <source>Border (small)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
2 rayas 1 punto (pequeño)</translatorcomment>
        <translation type="vanished">2 rayas 1 punto (pequeño)</translation>
    </message>
    <message>
        <source>Border (large)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
2 rayas 1 punto (grande)</translatorcomment>
        <translation type="vanished">2 rayas 1 punto (grande)</translation>
    </message>
    <message>
        <location filename="../src/core/RLinetype.cpp" line="+48"/>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Description</source>
        <translation>Descripción</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Metric</source>
        <translation>Métrico</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pattern</source>
        <translation>Patrón</translation>
    </message>
</context>
<context>
    <name>RLinetypePattern</name>
    <message>
        <location filename="../src/core/RLinetypePattern.cpp" line="+856"/>
        <source>By Layer</source>
        <translation>Por Capa</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Por Bloque</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Continuous</source>
        <translation>Contínua</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Border</source>
        <translation>Morse G</translation>
    </message>
    <message>
        <source>Border (2x)</source>
        <translation type="vanished">2 rayas 1 punto (2x)</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Center</source>
        <translation>Centro</translation>
    </message>
    <message>
        <source>Center (2x)</source>
        <translation type="vanished">Rayas larga corta (2x)</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dash dot</source>
        <translation>Trazo y punto</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dashed</source>
        <translation>Trazos</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Divide</source>
        <translation>Morse D</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dot</source>
        <translation>Puntos</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>Líneas ocultas</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Phantom</source>
        <translation>Vals</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>ISO dash</source>
        <translation>ISO trazo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash space</source>
        <translation>ISO trazo, espacio</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash dot</source>
        <translation>ISO trazo largo, punto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-dot</source>
        <translation>ISO trazo largo, doble punto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash triple-dot</source>
        <translation>ISO trazo largo, triple punto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dot</source>
        <translation>ISO punto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash short-dash</source>
        <translation>ISO trazo largo, trazo corto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-short-dash</source>
        <translation>ISO trazo largo, doble trazo corto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash dot</source>
        <translation>ISO trazo, punto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash dot</source>
        <translation>ISO doble trazo, punto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash double-dot</source>
        <translation>ISO trazo, doble punto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash double-dot</source>
        <translation>ISO doble trazo, doble punto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash triple-dot</source>
        <translation>ISO trazo, triple punto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash triple-dot</source>
        <translation>ISO doble trazo, triple punto</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Hot Water Supply</source>
        <translation>Agua caliente</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hot Water</source>
        <translation>Agua caliente</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gas Line</source>
        <translation>Gas</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Batting</source>
        <translation>Aislamiento</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Zig Zag</source>
        <translation>Zigzag</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tracks</source>
        <translation>Vías</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 1</source>
        <translation>Límite 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 2</source>
        <translation>Límite 2</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Drainage</source>
        <translation>Drenaje</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drainage Reversed</source>
        <translation>Drenaje reverso</translation>
    </message>
    <message>
        <source>Drainage Reverse</source>
        <translation type="vanished">Drenaje reverso</translation>
    </message>
</context>
<context>
    <name>RLineweight</name>
    <message>
        <location filename="../src/core/RLineweight.cpp" line="+35"/>
        <source>By Layer</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
Por Capa</translatorcomment>
        <translation>Por Capa</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
Por Bloque</translatorcomment>
        <translation>Por Bloque</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Default</source>
        <translatorcomment>--exact match--
--file: es.po--
Unidad por defecto
Unidad por defecto:</translatorcomment>
        <translation>Predeterminado</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.00mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
0.00mm</translatorcomment>
        <translation>0.00mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.05mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
0.05mm</translatorcomment>
        <translation>0.05mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.09mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
0.09mm</translatorcomment>
        <translation>0.09mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.13mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
0.13mm (ISO)</translatorcomment>
        <translation>0.13mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.15mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
0.15mm</translatorcomment>
        <translation>0.15mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.18mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
0.18mm (ISO)</translatorcomment>
        <translation>0.18mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.20mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
0.20mm</translatorcomment>
        <translation>0.20mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.25mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
0.25mm (ISO)</translatorcomment>
        <translation>0.25mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.30mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
0.30mm</translatorcomment>
        <translation>0.30mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.35mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
0.35mm (ISO)</translatorcomment>
        <translation>0.35mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.40mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
0.40mm</translatorcomment>
        <translation>0.40mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.50mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
0.50mm (ISO)</translatorcomment>
        <translation>0.50mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.53mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
0.53mm</translatorcomment>
        <translation>0.53mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.60mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
0.60mm</translatorcomment>
        <translation>0.60mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.70mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
0.70mm (ISO)</translatorcomment>
        <translation>0.70mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.80mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
0.80mm</translatorcomment>
        <translation>0.80mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.90mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
0.90mm</translatorcomment>
        <translation>0.90mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.00mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
1.00mm (ISO)</translatorcomment>
        <translation>1.00mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.06mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
1.06mm</translatorcomment>
        <translation>1.06mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.20mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
1.20mm</translatorcomment>
        <translation>1.20mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.40mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
1.40mm (ISO)</translatorcomment>
        <translation>1.40mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.58mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
1.58mm</translatorcomment>
        <translation>1.58mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.00mm (ISO)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
2.00mm (ISO)</translatorcomment>
        <translation>2.00mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.11mm</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_es.ts--
2.11mm</translatorcomment>
        <translation>2.11mm</translation>
    </message>
</context>
<context>
    <name>RObject</name>
    <message>
        <source>Custom</source>
        <translatorcomment>--exact match--
--file: es.po--
No objetos de dimensión seleccionados con una posición de texto personalizado.
No objetos de dimensión seleccionados con una posición de texto personalizado
Personalizado</translatorcomment>
        <translation type="vanished">Personalizado</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="vanished">Tipo</translation>
    </message>
    <message>
        <source>Handle</source>
        <translatorcomment>--exact match--
--file: es.po--
Secuencia ambigua %1 no tratada
Asa del deslizador</translatorcomment>
        <translation type="vanished">Handle</translation>
    </message>
    <message>
        <source>Protected</source>
        <translation type="vanished">Protegida</translation>
    </message>
</context>
</TS>
